=========
aqueduct3
=========


.. image:: https://pypi.python.org/pypi/aqueduct3.svg
        :target: https://pypi.python.org/pypi/aqueduct3

.. image:: https://travis-ci.org/rutgerhofste/aqueduct3.svg
        :target: https://travis-ci.org/rutgerhofste/aqueduct3

.. image:: https://readthedocs.org/projects/aqueduct3/badge/?version=latest
        :target: https://aqueduct3.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status
.. image:: https://pyup.io/repos/github/rutgerhofste/aqueduct3/shield.svg
        :target: https://pyup.io/account/repos/github/rutgerhofste/aqueduct3/



Python module for aqueduct program.

* Tutorial_  
* `Release Checklist`_
* Free software: MIT license
* Documentation: https://aqueduct3.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage

.. _Tutorial: https://cookiecutter-pypackage.readthedocs.io/en/latest/tutorial.html
.. _`Release Checklist`: https://gist.github.com/audreyr/5990987
